@@ -6,7 +6,7 @@ import tensorflow as tf
 
 class TimeSeriesInterpretorRNN:
 
-  def __init__(self,model,background,test,max_output,features,max_display,decision_range,Measure,dependence_feature_3):
+  def __init__(self,model,background,test,max_output,features,max_display,decision_range,Measure,dependence_feature_3,dependence_feature_2):
     self.model = model
     self.background = background
     self.test = test
@@ -16,6 +16,7 @@ class TimeSeriesInterpretorRNN:
     self.decision_range=decision_range
     self.Measure=Measure
     self.dependence_feature_3=dependence_feature_3
+    self.dependence_feature_2=dependence_feature_2
 
   def monthly_chart(self):
     model,background,test,features,max_output,Measure,dependence_feature_3= self.model,self.background,self.test,self.features,self.max_output,self.Measure,self.dependence_feature_3
@@ -88,7 +89,7 @@ class TimeSeriesInterpretorRNN:
     return shap.force_plot(e.expected_value, shap_values[0][0],test[0], feature_names=features,figsize= (20, 5))
     
   def global_patient(self):
-    model,background,test,features,max_display,decision_range,dependence_feature_3 = self.model,self.background,self.test,self.features,self.max_display,self.decision_range,self.dependence_feature_3
+    model,background,test,features,max_display,decision_range,dependence_feature_3,dependence_feature_2 = self.model,self.background,self.test,self.features,self.max_display,self.decision_range,self.dependence_feature_3,self.dependence_feature_2
     e = shap.DeepExplainer(model, background)
     shap_values = e.shap_values(test,check_additivity=False)
     d1=model.predict_generator(test)-e.expected_value
@@ -100,7 +101,7 @@ class TimeSeriesInterpretorRNN:
     p1=shap.summary_plot(shap_values[0][0],test[0],features,plot_type="bar",max_display=max_display)
     p2=shap.summary_plot(shap_values[0][0], test[0], feature_names=features,max_display=max_display)
     p3=shap.decision_plot(e.expected_value[0], shap_values[0][0], features,feature_display_range=slice(None, -decision_range, -1))
-    p4=shap.dependence_plot(0, shap_values[0][0],test[0], feature_names=features,interaction_index=dependence_feature_3)
+    p4=shap.dependence_plot(dependence_feature_2, shap_values[0][0],test[0], feature_names=features,interaction_index=dependence_feature_3)
     return p1,p2,p3,p4
   
   def single_month(self,month):
